diff --git a/core/modules/field/tests/src/Functional/Number/NumberFieldTest.php b/core/modules/field/tests/src/Functional/Number/NumberFieldTest.php
index 8ddf0b9e18d7b63e0f6053375dfe1b4d33a89f2c..24a7adab62fd86aeb7d4b749fd1bbcb6c3e0f2e8 100644
--- a/core/modules/field/tests/src/Functional/Number/NumberFieldTest.php
+++ b/core/modules/field/tests/src/Functional/Number/NumberFieldTest.php
@@ -13,7 +13,6 @@
  * Tests the creation of numeric fields.
  *
  * @group field
- * @group #slow
  */
 class NumberFieldTest extends BrowserTestBase {
 
@@ -393,9 +392,9 @@ public function testNumberFloatField(): void {
   }
 
   /**
    * Tests setting the minimum value of a float field through the interface.
    */
-  public function testCreateNumberFloatField(): void {
+  public function testMinimumValues(): void {
     // Create a float field.
     $field_name = $this->randomMachineName();
     FieldStorageConfig::create([
@@ -415,12 +414,7 @@ public function testCreateNumberFloatField(): void {
     $this->assertSetMinimumValue($field, 0.0001);
     // Set the minimum value to an integer value.
     $this->assertSetMinimumValue($field, 1);
-  }
 
-  /**
-   * Tests setting the minimum value of a decimal field through the interface.
-   */
-  public function testCreateNumberDecimalField(): void {
     // Create a decimal field.
     $field_name = $this->randomMachineName();
     FieldStorageConfig::create([
@@ -393,9 +392,9 @@ public function testNumberFloatField(): void {
 
   /**
-   * Tests setting the minimum value of a float field through the interface.
+   * Tests setting minimum values through the interface.
    */